RadioModel class

Constructors

RadioModel(bool? isSelected, String? icon, String? id, Color? selectedBtnColor, Color disabledBtnColor, Color selectedShadowColor, Color disabledShadowColor, BoxShape btnShape)

Properties

btnShape → BoxShape
final
disabledBtnColor → Color
final
disabledShadowColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String?
final
isSelected ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBtnColor → Color?
final
selectedShadowColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited