SideMenuItem class

Constructors

SideMenuItem({String? icon, String? id, bool? isSelected, Color? selectedBtnColor, Color disabledBtnColor = Colors.transparent, Color selectedShadowColor = Colors.blueGrey, Color disabledShadowColor = Colors.transparent, BoxShape btnShape = BoxShape.circle})

Properties

btnShape ↔ BoxShape
getter/setter pair
disabledBtnColor ↔ Color
getter/setter pair
disabledShadowColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String?
final
isSelected → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBtnColor → Color?
final
selectedShadowColor ↔ Color
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited